|debops_logo| DebOps Contrib playbooks
======================================

Ansible playbooks to run `DebOps Contrib <https://github.com/debops-contrib/debops-contrib>`_ roles.

Here are a few services that are available
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

**Fully loaded ready to go applications**

+-----------+---------------+
| foodsoft_ | volkszaehler_ |
+-----------+---------------+

**Service monitoring and logging**

+--------------------+-------------------+
| `Check_MK server`_ | `Check_MK agent`_ |
+--------------------+-------------------+

**System**

+-------+--------+---------------------+
| FUSE_ | BTRFS_ | `snapshot snapper`_ |
+-------+--------+---------------------+

**Security**

+-----------+-----------+---------------------+
| AppArmor_ | Firejail_ | dropbear-initramfs_ |
+-----------+-----------+---------------------+

**Workstations and clients**

+----------------+
| `X2Go Server`_ |
+----------------+

.. |debops_logo| image:: http://debops.org/images/debops-small.png

.. _foodsoft: https://github.com/debops-contrib/ansible-foodsoft
.. _volkszaehler: https://github.com/debops-contrib/ansible-volkszaehler

.. _`Check_MK server`: https://github.com/debops-contrib/ansible-checkmk_server
.. _`Check_MK agent`: https://github.com/debops-contrib/ansible-checkmk_agent

.. _FUSE: https://github.com/debops-contrib/ansible-fuse
.. _BTRFS: https://github.com/debops-contrib/ansible-btrfs
.. _`snapshot snapper`: https://github.com/debops-contrib/ansible-snapshot_snapper

.. _AppArmor: https://github.com/debops-contrib/ansible-apparmor
.. _Firejail: https://github.com/debops-contrib/ansible-firejail
.. _dropbear-initramfs: https://github.com/debops-contrib/ansible-dropbear_initramfs

.. _X2Go Server: https://github.com/debops-contrib/ansible-x2go_server
